==> libreoffice_24.2.7.orig-tarballs.tar.xz: curl-8.10.1/docs/SPONSORS.md <==
<!--
Copyright (C) Daniel Stenberg, <daniel@haxx.se>, et al.

SPDX-License-Identifier: curl
-->

# curl sponsors

A sponsor is someone who donates money or resources to the curl project for no
specific service in return.

curl accepts donations via [GitHub sponsors](https://github.com/sponsors/curl)
and [Open Collective](https://opencollective.com/curl).

An even better way to contribute to the project might be to pay an engineer or
two to spend work hours on curl related tasks.

We promise to use donated funds for things and activities that we believe are
beneficial for the project and its development. That includes but is not
limited to bug-bounties, developer conferences, infrastructure, development,
services and hardware.

Recurring donations above a certain amount of money puts the sponsor at a
named sponsor level: **Silver**, **Gold**, **Platinum** or **Top**.

Sponsors on a named level can provide their logo image and preferred URL and
get recognition on the curl website's [sponsor
page](https://curl.se/sponsors.html).

- **Silver Sponsor** at least 100 USD/month
- **Gold Sponsor** at least 500 USD/month
- **Platinum Sponsor** at least 1000 USD/month
- **Top Sponsor** outstanding extra valuable help

## Sponsor requirements

A named level sponsor is entitled a logo and link on the curl website assuming
the company, brand and link are not deemed unsuitable. The curl team reserves
the right to make that decision at its own discretion.

Sponsors may be denied a website presence for example if involved with drugs,
gambling, pornography, social media manipulation etc.

## Past Sponsors

Sponsors that stop paying are considered *Past Sponsors* and are not displayed
on the sponsor page anymore. We thank you for your contributions!

==> libreoffice_25.8.4~rc2.orig-tarballs.tar.xz: curl-8.14.1/docs/SPONSORS.md <==
<!--
Copyright (C) Daniel Stenberg, <daniel@haxx.se>, et al.

SPDX-License-Identifier: curl
-->

# curl sponsors

A sponsor is someone who donates money or resources to the curl project for no
specific service in return.

curl accepts donations via [GitHub sponsors](https://github.com/sponsors/curl)
and [Open Collective](https://opencollective.com/curl).

An even better way to contribute to the project might be to pay an engineer or
two to spend work hours on curl related tasks.

We promise to use donated funds for things and activities that we believe are
beneficial for the project and its development. That includes but is not
limited to bug-bounties, developer conferences, infrastructure, development,
services and hardware.

Recurring donations above a certain amount of money puts the sponsor at a
named sponsor level: **Silver**, **Gold**, **Platinum** or **Top**.

Sponsors on a named level can provide their logo image and preferred URL and
get recognition on the curl website's [sponsor
page](https://curl.se/sponsors.html), assuming they meet the project's
standards and requirements.

- **Silver Sponsor** at least 100 USD/month
- **Gold Sponsor** at least 500 USD/month
- **Platinum Sponsor** at least 1000 USD/month
- **Top Sponsor** outstanding extra valuable help

## Sponsor requirements

A named level sponsor is entitled a logo and link on the curl website assuming
the company, brand and link are not deemed unsuitable. The curl team reserves
the right to make that decision at its own discretion.

Sponsors may be denied a website presence for example if involved with drugs,
gambling, pornography, social media manipulation etc.

## Past Sponsors

Sponsors that stop paying are considered *Past Sponsors* and are not displayed
on the sponsor page anymore. We thank you for your contributions.

## Donations

Please note that sponsorship and donations are exactly that: donations to the
curl project. They are used to help and further the project as the project
leadership deems best. No goods or services are expected or promised in
return. Requests for refunds for such purposes are rejected.
